# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fibc/core/channel/v1/query.proto\x12\x13ibc.core.channel.v1\x1a\x1fibc/core/client/v1/client.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto\":\n\x13QueryChannelRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\"\x8c\x01\n\x14QueryChannelResponse\x12-\n\x07\x63hannel\x18\x01 \x01(\x0b\x32\x1c.ibc.core.channel.v1.Channel\x12\r\n\x05proof\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"R\n\x14QueryChannelsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xc0\x01\n\x15QueryChannelsResponse\x12\x38\n\x08\x63hannels\x18\x01 \x03(\x0b\x32&.ibc.core.channel.v1.IdentifiedChannel\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\x12\x30\n\x06height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"p\n\x1eQueryConnectionChannelsRequest\x12\x12\n\nconnection\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xca\x01\n\x1fQueryConnectionChannelsResponse\x12\x38\n\x08\x63hannels\x18\x01 \x03(\x0b\x32&.ibc.core.channel.v1.IdentifiedChannel\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\x12\x30\n\x06height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"E\n\x1eQueryChannelClientStateRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\"\xb4\x01\n\x1fQueryChannelClientStateResponse\x12J\n\x17identified_client_state\x18\x01 \x01(\x0b\x32).ibc.core.client.v1.IdentifiedClientState\x12\r\n\x05proof\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"z\n!QueryChannelConsensusStateRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x17\n\x0frevision_number\x18\x03 \x01(\x04\x12\x17\n\x0frevision_height\x18\x04 \x01(\x04\"\xad\x01\n\"QueryChannelConsensusStateResponse\x12-\n\x0f\x63onsensus_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\r\n\x05proof\x18\x03 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"U\n\x1cQueryPacketCommitmentRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04\"z\n\x1dQueryPacketCommitmentResponse\x12\x12\n\ncommitment\x18\x01 \x01(\x0c\x12\r\n\x05proof\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"\x80\x01\n\x1dQueryPacketCommitmentsRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xc6\x01\n\x1eQueryPacketCommitmentsResponse\x12\x35\n\x0b\x63ommitments\x18\x01 \x03(\x0b\x32 .ibc.core.channel.v1.PacketState\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\x12\x30\n\x06height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"R\n\x19QueryPacketReceiptRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04\"u\n\x1aQueryPacketReceiptResponse\x12\x10\n\x08received\x18\x02 \x01(\x08\x12\r\n\x05proof\x18\x03 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"Z\n!QueryPacketAcknowledgementRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04\"\x84\x01\n\"QueryPacketAcknowledgementResponse\x12\x17\n\x0f\x61\x63knowledgement\x18\x01 \x01(\x0c\x12\r\n\x05proof\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"\xaa\x01\n\"QueryPacketAcknowledgementsRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x12#\n\x1bpacket_commitment_sequences\x18\x04 \x03(\x04\"\xd0\x01\n#QueryPacketAcknowledgementsResponse\x12:\n\x10\x61\x63knowledgements\x18\x01 \x03(\x0b\x32 .ibc.core.channel.v1.PacketState\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\x12\x30\n\x06height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"i\n\x1dQueryUnreceivedPacketsRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12#\n\x1bpacket_commitment_sequences\x18\x03 \x03(\x04\"e\n\x1eQueryUnreceivedPacketsResponse\x12\x11\n\tsequences\x18\x01 \x03(\x04\x12\x30\n\x06height\x18\x02 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"_\n\x1aQueryUnreceivedAcksRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x1c\n\x14packet_ack_sequences\x18\x03 \x03(\x04\"b\n\x1bQueryUnreceivedAcksResponse\x12\x11\n\tsequences\x18\x01 \x03(\x04\x12\x30\n\x06height\x18\x02 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"F\n\x1fQueryNextSequenceReceiveRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\"\x88\x01\n QueryNextSequenceReceiveResponse\x12\x1d\n\x15next_sequence_receive\x18\x01 \x01(\x04\x12\r\n\x05proof\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x32\x8b\x16\n\x05Query\x12\xa2\x01\n\x07\x43hannel\x12(.ibc.core.channel.v1.QueryChannelRequest\x1a).ibc.core.channel.v1.QueryChannelResponse\"B\x82\xd3\xe4\x93\x02<\x12:/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}\x12\x88\x01\n\x08\x43hannels\x12).ibc.core.channel.v1.QueryChannelsRequest\x1a*.ibc.core.channel.v1.QueryChannelsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/ibc/core/channel/v1/channels\x12\xbf\x01\n\x12\x43onnectionChannels\x12\x33.ibc.core.channel.v1.QueryConnectionChannelsRequest\x1a\x34.ibc.core.channel.v1.QueryConnectionChannelsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/ibc/core/channel/v1/connections/{connection}/channels\x12\xd0\x01\n\x12\x43hannelClientState\x12\x33.ibc.core.channel.v1.QueryChannelClientStateRequest\x1a\x34.ibc.core.channel.v1.QueryChannelClientStateResponse\"O\x82\xd3\xe4\x93\x02I\x12G/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/client_state\x12\x92\x02\n\x15\x43hannelConsensusState\x12\x36.ibc.core.channel.v1.QueryChannelConsensusStateRequest\x1a\x37.ibc.core.channel.v1.QueryChannelConsensusStateResponse\"\x87\x01\x82\xd3\xe4\x93\x02\x80\x01\x12~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/consensus_state/revision/{revision_number}/height/{revision_height}\x12\xdb\x01\n\x10PacketCommitment\x12\x31.ibc.core.channel.v1.QueryPacketCommitmentRequest\x1a\x32.ibc.core.channel.v1.QueryPacketCommitmentResponse\"`\x82\xd3\xe4\x93\x02Z\x12X/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{sequence}\x12\xd3\x01\n\x11PacketCommitments\x12\x32.ibc.core.channel.v1.QueryPacketCommitmentsRequest\x1a\x33.ibc.core.channel.v1.QueryPacketCommitmentsResponse\"U\x82\xd3\xe4\x93\x02O\x12M/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments\x12\xcf\x01\n\rPacketReceipt\x12..ibc.core.channel.v1.QueryPacketReceiptRequest\x1a/.ibc.core.channel.v1.QueryPacketReceiptResponse\"]\x82\xd3\xe4\x93\x02W\x12U/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_receipts/{sequence}\x12\xe3\x01\n\x15PacketAcknowledgement\x12\x36.ibc.core.channel.v1.QueryPacketAcknowledgementRequest\x1a\x37.ibc.core.channel.v1.QueryPacketAcknowledgementResponse\"Y\x82\xd3\xe4\x93\x02S\x12Q/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acks/{sequence}\x12\xe7\x01\n\x16PacketAcknowledgements\x12\x37.ibc.core.channel.v1.QueryPacketAcknowledgementsRequest\x1a\x38.ibc.core.channel.v1.QueryPacketAcknowledgementsResponse\"Z\x82\xd3\xe4\x93\x02T\x12R/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acknowledgements\x12\x86\x02\n\x11UnreceivedPackets\x12\x32.ibc.core.channel.v1.QueryUnreceivedPacketsRequest\x1a\x33.ibc.core.channel.v1.QueryUnreceivedPacketsResponse\"\x87\x01\x82\xd3\xe4\x93\x02\x80\x01\x12~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_commitment_sequences}/unreceived_packets\x12\xf1\x01\n\x0eUnreceivedAcks\x12/.ibc.core.channel.v1.QueryUnreceivedAcksRequest\x1a\x30.ibc.core.channel.v1.QueryUnreceivedAcksResponse\"|\x82\xd3\xe4\x93\x02v\x12t/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_ack_sequences}/unreceived_acks\x12\xd4\x01\n\x13NextSequenceReceive\x12\x34.ibc.core.channel.v1.QueryNextSequenceReceiveRequest\x1a\x35.ibc.core.channel.v1.QueryNextSequenceReceiveResponse\"P\x82\xd3\xe4\x93\x02J\x12H/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/next_sequenceB;Z9github.com/cosmos/ibc-go/v2/modules/core/04-channel/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/cosmos/ibc-go/v2/modules/core/04-channel/types'
  _QUERYCHANNELRESPONSE.fields_by_name['proof_height']._options = None
  _QUERYCHANNELRESPONSE.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _QUERYCHANNELSRESPONSE.fields_by_name['height']._options = None
  _QUERYCHANNELSRESPONSE.fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _QUERYCONNECTIONCHANNELSRESPONSE.fields_by_name['height']._options = None
  _QUERYCONNECTIONCHANNELSRESPONSE.fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _QUERYCHANNELCLIENTSTATERESPONSE.fields_by_name['proof_height']._options = None
  _QUERYCHANNELCLIENTSTATERESPONSE.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _QUERYCHANNELCONSENSUSSTATERESPONSE.fields_by_name['proof_height']._options = None
  _QUERYCHANNELCONSENSUSSTATERESPONSE.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _QUERYPACKETCOMMITMENTRESPONSE.fields_by_name['proof_height']._options = None
  _QUERYPACKETCOMMITMENTRESPONSE.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _QUERYPACKETCOMMITMENTSRESPONSE.fields_by_name['height']._options = None
  _QUERYPACKETCOMMITMENTSRESPONSE.fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _QUERYPACKETRECEIPTRESPONSE.fields_by_name['proof_height']._options = None
  _QUERYPACKETRECEIPTRESPONSE.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _QUERYPACKETACKNOWLEDGEMENTRESPONSE.fields_by_name['proof_height']._options = None
  _QUERYPACKETACKNOWLEDGEMENTRESPONSE.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _QUERYPACKETACKNOWLEDGEMENTSRESPONSE.fields_by_name['height']._options = None
  _QUERYPACKETACKNOWLEDGEMENTSRESPONSE.fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _QUERYUNRECEIVEDPACKETSRESPONSE.fields_by_name['height']._options = None
  _QUERYUNRECEIVEDPACKETSRESPONSE.fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _QUERYUNRECEIVEDACKSRESPONSE.fields_by_name['height']._options = None
  _QUERYUNRECEIVEDACKSRESPONSE.fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _QUERYNEXTSEQUENCERECEIVERESPONSE.fields_by_name['proof_height']._options = None
  _QUERYNEXTSEQUENCERECEIVERESPONSE.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['Channel']._options = None
  _QUERY.methods_by_name['Channel']._serialized_options = b'\202\323\344\223\002<\022:/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}'
  _QUERY.methods_by_name['Channels']._options = None
  _QUERY.methods_by_name['Channels']._serialized_options = b'\202\323\344\223\002\037\022\035/ibc/core/channel/v1/channels'
  _QUERY.methods_by_name['ConnectionChannels']._options = None
  _QUERY.methods_by_name['ConnectionChannels']._serialized_options = b'\202\323\344\223\0028\0226/ibc/core/channel/v1/connections/{connection}/channels'
  _QUERY.methods_by_name['ChannelClientState']._options = None
  _QUERY.methods_by_name['ChannelClientState']._serialized_options = b'\202\323\344\223\002I\022G/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/client_state'
  _QUERY.methods_by_name['ChannelConsensusState']._options = None
  _QUERY.methods_by_name['ChannelConsensusState']._serialized_options = b'\202\323\344\223\002\200\001\022~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/consensus_state/revision/{revision_number}/height/{revision_height}'
  _QUERY.methods_by_name['PacketCommitment']._options = None
  _QUERY.methods_by_name['PacketCommitment']._serialized_options = b'\202\323\344\223\002Z\022X/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{sequence}'
  _QUERY.methods_by_name['PacketCommitments']._options = None
  _QUERY.methods_by_name['PacketCommitments']._serialized_options = b'\202\323\344\223\002O\022M/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments'
  _QUERY.methods_by_name['PacketReceipt']._options = None
  _QUERY.methods_by_name['PacketReceipt']._serialized_options = b'\202\323\344\223\002W\022U/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_receipts/{sequence}'
  _QUERY.methods_by_name['PacketAcknowledgement']._options = None
  _QUERY.methods_by_name['PacketAcknowledgement']._serialized_options = b'\202\323\344\223\002S\022Q/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acks/{sequence}'
  _QUERY.methods_by_name['PacketAcknowledgements']._options = None
  _QUERY.methods_by_name['PacketAcknowledgements']._serialized_options = b'\202\323\344\223\002T\022R/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acknowledgements'
  _QUERY.methods_by_name['UnreceivedPackets']._options = None
  _QUERY.methods_by_name['UnreceivedPackets']._serialized_options = b'\202\323\344\223\002\200\001\022~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_commitment_sequences}/unreceived_packets'
  _QUERY.methods_by_name['UnreceivedAcks']._options = None
  _QUERY.methods_by_name['UnreceivedAcks']._serialized_options = b'\202\323\344\223\002v\022t/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_ack_sequences}/unreceived_acks'
  _QUERY.methods_by_name['NextSequenceReceive']._options = None
  _QUERY.methods_by_name['NextSequenceReceive']._serialized_options = b'\202\323\344\223\002J\022H/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/next_sequence'
  _QUERYCHANNELREQUEST._serialized_start=247
  _QUERYCHANNELREQUEST._serialized_end=305
  _QUERYCHANNELRESPONSE._serialized_start=308
  _QUERYCHANNELRESPONSE._serialized_end=448
  _QUERYCHANNELSREQUEST._serialized_start=450
  _QUERYCHANNELSREQUEST._serialized_end=532
  _QUERYCHANNELSRESPONSE._serialized_start=535
  _QUERYCHANNELSRESPONSE._serialized_end=727
  _QUERYCONNECTIONCHANNELSREQUEST._serialized_start=729
  _QUERYCONNECTIONCHANNELSREQUEST._serialized_end=841
  _QUERYCONNECTIONCHANNELSRESPONSE._serialized_start=844
  _QUERYCONNECTIONCHANNELSRESPONSE._serialized_end=1046
  _QUERYCHANNELCLIENTSTATEREQUEST._serialized_start=1048
  _QUERYCHANNELCLIENTSTATEREQUEST._serialized_end=1117
  _QUERYCHANNELCLIENTSTATERESPONSE._serialized_start=1120
  _QUERYCHANNELCLIENTSTATERESPONSE._serialized_end=1300
  _QUERYCHANNELCONSENSUSSTATEREQUEST._serialized_start=1302
  _QUERYCHANNELCONSENSUSSTATEREQUEST._serialized_end=1424
  _QUERYCHANNELCONSENSUSSTATERESPONSE._serialized_start=1427
  _QUERYCHANNELCONSENSUSSTATERESPONSE._serialized_end=1600
  _QUERYPACKETCOMMITMENTREQUEST._serialized_start=1602
  _QUERYPACKETCOMMITMENTREQUEST._serialized_end=1687
  _QUERYPACKETCOMMITMENTRESPONSE._serialized_start=1689
  _QUERYPACKETCOMMITMENTRESPONSE._serialized_end=1811
  _QUERYPACKETCOMMITMENTSREQUEST._serialized_start=1814
  _QUERYPACKETCOMMITMENTSREQUEST._serialized_end=1942
  _QUERYPACKETCOMMITMENTSRESPONSE._serialized_start=1945
  _QUERYPACKETCOMMITMENTSRESPONSE._serialized_end=2143
  _QUERYPACKETRECEIPTREQUEST._serialized_start=2145
  _QUERYPACKETRECEIPTREQUEST._serialized_end=2227
  _QUERYPACKETRECEIPTRESPONSE._serialized_start=2229
  _QUERYPACKETRECEIPTRESPONSE._serialized_end=2346
  _QUERYPACKETACKNOWLEDGEMENTREQUEST._serialized_start=2348
  _QUERYPACKETACKNOWLEDGEMENTREQUEST._serialized_end=2438
  _QUERYPACKETACKNOWLEDGEMENTRESPONSE._serialized_start=2441
  _QUERYPACKETACKNOWLEDGEMENTRESPONSE._serialized_end=2573
  _QUERYPACKETACKNOWLEDGEMENTSREQUEST._serialized_start=2576
  _QUERYPACKETACKNOWLEDGEMENTSREQUEST._serialized_end=2746
  _QUERYPACKETACKNOWLEDGEMENTSRESPONSE._serialized_start=2749
  _QUERYPACKETACKNOWLEDGEMENTSRESPONSE._serialized_end=2957
  _QUERYUNRECEIVEDPACKETSREQUEST._serialized_start=2959
  _QUERYUNRECEIVEDPACKETSREQUEST._serialized_end=3064
  _QUERYUNRECEIVEDPACKETSRESPONSE._serialized_start=3066
  _QUERYUNRECEIVEDPACKETSRESPONSE._serialized_end=3167
  _QUERYUNRECEIVEDACKSREQUEST._serialized_start=3169
  _QUERYUNRECEIVEDACKSREQUEST._serialized_end=3264
  _QUERYUNRECEIVEDACKSRESPONSE._serialized_start=3266
  _QUERYUNRECEIVEDACKSRESPONSE._serialized_end=3364
  _QUERYNEXTSEQUENCERECEIVEREQUEST._serialized_start=3366
  _QUERYNEXTSEQUENCERECEIVEREQUEST._serialized_end=3436
  _QUERYNEXTSEQUENCERECEIVERESPONSE._serialized_start=3439
  _QUERYNEXTSEQUENCERECEIVERESPONSE._serialized_end=3575
  _QUERY._serialized_start=3578
  _QUERY._serialized_end=6405
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/channel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/core/channel/v1/channel.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto\"\xed\x01\n\x07\x43hannel\x12)\n\x05state\x18\x01 \x01(\x0e\x32\x1a.ibc.core.channel.v1.State\x12,\n\x08ordering\x18\x02 \x01(\x0e\x32\x1a.ibc.core.channel.v1.Order\x12=\n\x0c\x63ounterparty\x18\x03 \x01(\x0b\x32!.ibc.core.channel.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12\x33\n\x0f\x63onnection_hops\x18\x04 \x03(\tB\x1a\xf2\xde\x1f\x16yaml:\"connection_hops\"\x12\x0f\n\x07version\x18\x05 \x01(\t:\x04\x88\xa0\x1f\x00\"\x9c\x02\n\x11IdentifiedChannel\x12)\n\x05state\x18\x01 \x01(\x0e\x32\x1a.ibc.core.channel.v1.State\x12,\n\x08ordering\x18\x02 \x01(\x0e\x32\x1a.ibc.core.channel.v1.Order\x12=\n\x0c\x63ounterparty\x18\x03 \x01(\x0b\x32!.ibc.core.channel.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12\x33\n\x0f\x63onnection_hops\x18\x04 \x03(\tB\x1a\xf2\xde\x1f\x16yaml:\"connection_hops\"\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x0f\n\x07port_id\x18\x06 \x01(\t\x12\x12\n\nchannel_id\x18\x07 \x01(\t:\x04\x88\xa0\x1f\x00\"d\n\x0c\x43ounterparty\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\":\x04\x88\xa0\x1f\x00\"\x8e\x03\n\x06Packet\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12+\n\x0bsource_port\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"source_port\"\x12\x31\n\x0esource_channel\x18\x03 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_channel\"\x12\x35\n\x10\x64\x65stination_port\x18\x04 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"destination_port\"\x12;\n\x13\x64\x65stination_channel\x18\x05 \x01(\tB\x1e\xf2\xde\x1f\x1ayaml:\"destination_channel\"\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12Q\n\x0etimeout_height\x18\x07 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1d\xf2\xde\x1f\x15yaml:\"timeout_height\"\xc8\xde\x1f\x00\x12\x37\n\x11timeout_timestamp\x18\x08 \x01(\x04\x42\x1c\xf2\xde\x1f\x18yaml:\"timeout_timestamp\":\x04\x88\xa0\x1f\x00\"\x83\x01\n\x0bPacketState\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c:\x04\x88\xa0\x1f\x00\"@\n\x0f\x41\x63knowledgement\x12\x10\n\x06result\x18\x15 \x01(\x0cH\x00\x12\x0f\n\x05\x65rror\x18\x16 \x01(\tH\x00\x42\n\n\x08response*\xb7\x01\n\x05State\x12\x36\n\x1fSTATE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x11\x8a\x9d \rUNINITIALIZED\x12\x18\n\nSTATE_INIT\x10\x01\x1a\x08\x8a\x9d \x04INIT\x12\x1e\n\rSTATE_TRYOPEN\x10\x02\x1a\x0b\x8a\x9d \x07TRYOPEN\x12\x18\n\nSTATE_OPEN\x10\x03\x1a\x08\x8a\x9d \x04OPEN\x12\x1c\n\x0cSTATE_CLOSED\x10\x04\x1a\n\x8a\x9d \x06\x43LOSED\x1a\x04\x88\xa3\x1e\x00*w\n\x05Order\x12$\n\x16ORDER_NONE_UNSPECIFIED\x10\x00\x1a\x08\x8a\x9d \x04NONE\x12\"\n\x0fORDER_UNORDERED\x10\x01\x1a\r\x8a\x9d \tUNORDERED\x12\x1e\n\rORDER_ORDERED\x10\x02\x1a\x0b\x8a\x9d \x07ORDERED\x1a\x04\x88\xa3\x1e\x00\x42;Z9github.com/cosmos/ibc-go/v2/modules/core/04-channel/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.channel_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/cosmos/ibc-go/v2/modules/core/04-channel/types'
  _STATE._options = None
  _STATE._serialized_options = b'\210\243\036\000'
  _STATE.values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._options = None
  _STATE.values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._serialized_options = b'\212\235 \rUNINITIALIZED'
  _STATE.values_by_name["STATE_INIT"]._options = None
  _STATE.values_by_name["STATE_INIT"]._serialized_options = b'\212\235 \004INIT'
  _STATE.values_by_name["STATE_TRYOPEN"]._options = None
  _STATE.values_by_name["STATE_TRYOPEN"]._serialized_options = b'\212\235 \007TRYOPEN'
  _STATE.values_by_name["STATE_OPEN"]._options = None
  _STATE.values_by_name["STATE_OPEN"]._serialized_options = b'\212\235 \004OPEN'
  _STATE.values_by_name["STATE_CLOSED"]._options = None
  _STATE.values_by_name["STATE_CLOSED"]._serialized_options = b'\212\235 \006CLOSED'
  _ORDER._options = None
  _ORDER._serialized_options = b'\210\243\036\000'
  _ORDER.values_by_name["ORDER_NONE_UNSPECIFIED"]._options = None
  _ORDER.values_by_name["ORDER_NONE_UNSPECIFIED"]._serialized_options = b'\212\235 \004NONE'
  _ORDER.values_by_name["ORDER_UNORDERED"]._options = None
  _ORDER.values_by_name["ORDER_UNORDERED"]._serialized_options = b'\212\235 \tUNORDERED'
  _ORDER.values_by_name["ORDER_ORDERED"]._options = None
  _ORDER.values_by_name["ORDER_ORDERED"]._serialized_options = b'\212\235 \007ORDERED'
  _CHANNEL.fields_by_name['counterparty']._options = None
  _CHANNEL.fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _CHANNEL.fields_by_name['connection_hops']._options = None
  _CHANNEL.fields_by_name['connection_hops']._serialized_options = b'\362\336\037\026yaml:\"connection_hops\"'
  _CHANNEL._options = None
  _CHANNEL._serialized_options = b'\210\240\037\000'
  _IDENTIFIEDCHANNEL.fields_by_name['counterparty']._options = None
  _IDENTIFIEDCHANNEL.fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _IDENTIFIEDCHANNEL.fields_by_name['connection_hops']._options = None
  _IDENTIFIEDCHANNEL.fields_by_name['connection_hops']._serialized_options = b'\362\336\037\026yaml:\"connection_hops\"'
  _IDENTIFIEDCHANNEL._options = None
  _IDENTIFIEDCHANNEL._serialized_options = b'\210\240\037\000'
  _COUNTERPARTY.fields_by_name['port_id']._options = None
  _COUNTERPARTY.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _COUNTERPARTY.fields_by_name['channel_id']._options = None
  _COUNTERPARTY.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _COUNTERPARTY._options = None
  _COUNTERPARTY._serialized_options = b'\210\240\037\000'
  _PACKET.fields_by_name['source_port']._options = None
  _PACKET.fields_by_name['source_port']._serialized_options = b'\362\336\037\022yaml:\"source_port\"'
  _PACKET.fields_by_name['source_channel']._options = None
  _PACKET.fields_by_name['source_channel']._serialized_options = b'\362\336\037\025yaml:\"source_channel\"'
  _PACKET.fields_by_name['destination_port']._options = None
  _PACKET.fields_by_name['destination_port']._serialized_options = b'\362\336\037\027yaml:\"destination_port\"'
  _PACKET.fields_by_name['destination_channel']._options = None
  _PACKET.fields_by_name['destination_channel']._serialized_options = b'\362\336\037\032yaml:\"destination_channel\"'
  _PACKET.fields_by_name['timeout_height']._options = None
  _PACKET.fields_by_name['timeout_height']._serialized_options = b'\362\336\037\025yaml:\"timeout_height\"\310\336\037\000'
  _PACKET.fields_by_name['timeout_timestamp']._options = None
  _PACKET.fields_by_name['timeout_timestamp']._serialized_options = b'\362\336\037\030yaml:\"timeout_timestamp\"'
  _PACKET._options = None
  _PACKET._serialized_options = b'\210\240\037\000'
  _PACKETSTATE.fields_by_name['port_id']._options = None
  _PACKETSTATE.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _PACKETSTATE.fields_by_name['channel_id']._options = None
  _PACKETSTATE.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _PACKETSTATE._options = None
  _PACKETSTATE._serialized_options = b'\210\240\037\000'
  _STATE._serialized_start=1344
  _STATE._serialized_end=1527
  _ORDER._serialized_start=1529
  _ORDER._serialized_end=1648
  _CHANNEL._serialized_start=114
  _CHANNEL._serialized_end=351
  _IDENTIFIEDCHANNEL._serialized_start=354
  _IDENTIFIEDCHANNEL._serialized_end=638
  _COUNTERPARTY._serialized_start=640
  _COUNTERPARTY._serialized_end=740
  _PACKET._serialized_start=743
  _PACKET._serialized_end=1141
  _PACKETSTATE._serialized_start=1144
  _PACKETSTATE._serialized_end=1275
  _ACKNOWLEDGEMENT._serialized_start=1277
  _ACKNOWLEDGEMENT._serialized_end=1341
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.wasmx.v1 import wasmx_pb2 as injective_dot_wasmx_dot_v1_dot_wasmx__pb2
from injective.wasmx.v1 import genesis_pb2 as injective_dot_wasmx_dot_v1_dot_genesis__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/wasmx/v1/query.proto\x12\x12injective.wasmx.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1einjective/wasmx/v1/wasmx.proto\x1a injective/wasmx/v1/genesis.proto\x1a\x14gogoproto/gogo.proto\"\x19\n\x17QueryWasmxParamsRequest\"L\n\x18QueryWasmxParamsResponse\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.injective.wasmx.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x19\n\x17QueryModuleStateRequest\"K\n\x18QueryModuleStateResponse\x12/\n\x05state\x18\x01 \x01(\x0b\x32 .injective.wasmx.v1.GenesisState\"@\n$QueryContractRegistrationInfoRequest\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\"a\n%QueryContractRegistrationInfoResponse\x12\x38\n\x08\x63ontract\x18\x01 \x01(\x0b\x32&.injective.wasmx.v1.RegisteredContract2\xb0\x02\n\x05Query\x12\x8c\x01\n\x0bWasmxParams\x12+.injective.wasmx.v1.QueryWasmxParamsRequest\x1a,.injective.wasmx.v1.QueryWasmxParamsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/injective/wasmx/v1/params\x12\x97\x01\n\x10WasmxModuleState\x12+.injective.wasmx.v1.QueryModuleStateRequest\x1a,.injective.wasmx.v1.QueryModuleStateResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /injective/wasmx/v1/module_stateBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types'
  _QUERYWASMXPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYWASMXPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['WasmxParams']._options = None
  _QUERY.methods_by_name['WasmxParams']._serialized_options = b'\202\323\344\223\002\034\022\032/injective/wasmx/v1/params'
  _QUERY.methods_by_name['WasmxModuleState']._options = None
  _QUERY.methods_by_name['WasmxModuleState']._serialized_options = b'\202\323\344\223\002\"\022 /injective/wasmx/v1/module_state'
  _QUERYWASMXPARAMSREQUEST._serialized_start=172
  _QUERYWASMXPARAMSREQUEST._serialized_end=197
  _QUERYWASMXPARAMSRESPONSE._serialized_start=199
  _QUERYWASMXPARAMSRESPONSE._serialized_end=275
  _QUERYMODULESTATEREQUEST._serialized_start=277
  _QUERYMODULESTATEREQUEST._serialized_end=302
  _QUERYMODULESTATERESPONSE._serialized_start=304
  _QUERYMODULESTATERESPONSE._serialized_end=379
  _QUERYCONTRACTREGISTRATIONINFOREQUEST._serialized_start=381
  _QUERYCONTRACTREGISTRATIONINFOREQUEST._serialized_end=445
  _QUERYCONTRACTREGISTRATIONINFORESPONSE._serialized_start=447
  _QUERYCONTRACTREGISTRATIONINFORESPONSE._serialized_end=544
  _QUERY._serialized_start=547
  _QUERY._serialized_end=851
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.tokenfactory.v1beta1 import authorityMetadata_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_authorityMetadata__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+injective/tokenfactory/v1beta1/params.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x36injective/tokenfactory/v1beta1/authorityMetadata.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x8f\x01\n\x06Params\x12\x84\x01\n\x12\x64\x65nom_creation_fee\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBM\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x19yaml:\"denom_creation_fee\"\xc8\xde\x1f\x00\x42TZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.params_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types'
  _PARAMS.fields_by_name['denom_creation_fee']._options = None
  _PARAMS.fields_by_name['denom_creation_fee']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\031yaml:\"denom_creation_fee\"\310\336\037\000'
  _PARAMS._serialized_start=217
  _PARAMS._serialized_end=360
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.insurance.v1beta1 import insurance_pb2 as injective_dot_insurance_dot_v1beta1_dot_insurance__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)injective/insurance/v1beta1/genesis.proto\x12\x1binjective.insurance.v1beta1\x1a+injective/insurance/v1beta1/insurance.proto\x1a\x14gogoproto/gogo.proto\"\xaa\x02\n\x0cGenesisState\x12\x39\n\x06params\x18\x01 \x01(\x0b\x32#.injective.insurance.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12I\n\x0finsurance_funds\x18\x02 \x03(\x0b\x32*.injective.insurance.v1beta1.InsuranceFundB\x04\xc8\xde\x1f\x00\x12R\n\x13redemption_schedule\x18\x03 \x03(\x0b\x32/.injective.insurance.v1beta1.RedemptionScheduleB\x04\xc8\xde\x1f\x00\x12\x1b\n\x13next_share_denom_id\x18\x04 \x01(\x04\x12#\n\x1bnext_redemption_schedule_id\x18\x05 \x01(\x04\x42QZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.insurance.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['insurance_funds']._options = None
  _GENESISSTATE.fields_by_name['insurance_funds']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['redemption_schedule']._options = None
  _GENESISSTATE.fields_by_name['redemption_schedule']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=142
  _GENESISSTATE._serialized_end=440
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/types/canonical.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/types/canonical.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/types/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"i\n\x10\x43\x61nonicalBlockID\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12G\n\x0fpart_set_header\x18\x02 \x01(\x0b\x32(.tendermint.types.CanonicalPartSetHeaderB\x04\xc8\xde\x1f\x00\"5\n\x16\x43\x61nonicalPartSetHeader\x12\r\n\x05total\x18\x01 \x01(\r\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"\x9d\x02\n\x11\x43\x61nonicalProposal\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x10\x12\r\n\x05round\x18\x03 \x01(\x10\x12\x1f\n\tpol_round\x18\x04 \x01(\x03\x42\x0c\xe2\xde\x1f\x08POLRound\x12\x41\n\x08\x62lock_id\x18\x05 \x01(\x0b\x32\".tendermint.types.CanonicalBlockIDB\x0b\xe2\xde\x1f\x07\x42lockID\x12\x37\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1d\n\x08\x63hain_id\x18\x07 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\"\xf8\x01\n\rCanonicalVote\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x10\x12\r\n\x05round\x18\x03 \x01(\x10\x12\x41\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\".tendermint.types.CanonicalBlockIDB\x0b\xe2\xde\x1f\x07\x42lockID\x12\x37\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1d\n\x08\x63hain_id\x18\x06 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainIDB9Z7github.com/tendermint/tendermint/proto/tendermint/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.canonical_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/types'
  _CANONICALBLOCKID.fields_by_name['part_set_header']._options = None
  _CANONICALBLOCKID.fields_by_name['part_set_header']._serialized_options = b'\310\336\037\000'
  _CANONICALPROPOSAL.fields_by_name['pol_round']._options = None
  _CANONICALPROPOSAL.fields_by_name['pol_round']._serialized_options = b'\342\336\037\010POLRound'
  _CANONICALPROPOSAL.fields_by_name['block_id']._options = None
  _CANONICALPROPOSAL.fields_by_name['block_id']._serialized_options = b'\342\336\037\007BlockID'
  _CANONICALPROPOSAL.fields_by_name['timestamp']._options = None
  _CANONICALPROPOSAL.fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _CANONICALPROPOSAL.fields_by_name['chain_id']._options = None
  _CANONICALPROPOSAL.fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _CANONICALVOTE.fields_by_name['block_id']._options = None
  _CANONICALVOTE.fields_by_name['block_id']._serialized_options = b'\342\336\037\007BlockID'
  _CANONICALVOTE.fields_by_name['timestamp']._options = None
  _CANONICALVOTE.fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _CANONICALVOTE.fields_by_name['chain_id']._options = None
  _CANONICALVOTE.fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _CANONICALBLOCKID._serialized_start=139
  _CANONICALBLOCKID._serialized_end=244
  _CANONICALPARTSETHEADER._serialized_start=246
  _CANONICALPARTSETHEADER._serialized_end=299
  _CANONICALPROPOSAL._serialized_start=302
  _CANONICALPROPOSAL._serialized_end=587
  _CANONICALVOTE._serialized_start=590
  _CANONICALVOTE._serialized_end=838
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/insurance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+injective/insurance/v1beta1/insurance.proto\x12\x1binjective.insurance.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x9b\x01\n\x06Params\x12\x8a\x01\n)default_redemption_notice_period_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB<\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x30yaml:\"default_redemption_notice_period_duration\":\x04\xe8\xa0\x1f\x01\"\xec\x03\n\rInsuranceFund\x12\x15\n\rdeposit_denom\x18\x01 \x01(\t\x12\"\n\x1ainsurance_pool_token_denom\x18\x02 \x01(\t\x12z\n!redemption_notice_period_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB4\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f(yaml:\"redemption_notice_period_duration\"\x12?\n\x07\x62\x61lance\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x43\n\x0btotal_share\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x11\n\tmarket_id\x18\x06 \x01(\t\x12\x15\n\rmarket_ticker\x18\x07 \x01(\t\x12\x13\n\x0boracle_base\x18\x08 \x01(\t\x12\x14\n\x0coracle_quote\x18\t \x01(\t\x12\x39\n\x0boracle_type\x18\n \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x0e\n\x06\x65xpiry\x18\x0b \x01(\x03\"\xed\x01\n\x12RedemptionSchedule\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08marketId\x18\x02 \x01(\t\x12\x10\n\x08redeemer\x18\x03 \x01(\t\x12k\n\x19\x63laimable_redemption_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB,\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f yaml:\"claimable_redemption_time\"\x12:\n\x11redemption_amount\x18\x05 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"T\n\x18\x45ventInsuranceFundUpdate\x12\x38\n\x04\x66und\x18\x01 \x01(\x0b\x32*.injective.insurance.v1beta1.InsuranceFund\"[\n\x16\x45ventRequestRedemption\x12\x41\n\x08schedule\x18\x01 \x01(\x0b\x32/.injective.insurance.v1beta1.RedemptionSchedule\"\x92\x01\n\x17\x45ventWithdrawRedemption\x12\x41\n\x08schedule\x18\x01 \x01(\x0b\x32/.injective.insurance.v1beta1.RedemptionSchedule\x12\x34\n\x0bredeem_coin\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x9b\x01\n\x0f\x45ventUnderwrite\x12\x13\n\x0bunderwriter\x18\x01 \x01(\t\x12\x10\n\x08marketId\x18\x02 \x01(\t\x12\x30\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12/\n\x06shares\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x42QZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.insurance.v1beta1.insurance_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types'
  _PARAMS.fields_by_name['default_redemption_notice_period_duration']._options = None
  _PARAMS.fields_by_name['default_redemption_notice_period_duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\0370yaml:\"default_redemption_notice_period_duration\"'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\350\240\037\001'
  _INSURANCEFUND.fields_by_name['redemption_notice_period_duration']._options = None
  _INSURANCEFUND.fields_by_name['redemption_notice_period_duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037(yaml:\"redemption_notice_period_duration\"'
  _INSURANCEFUND.fields_by_name['balance']._options = None
  _INSURANCEFUND.fields_by_name['balance']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _INSURANCEFUND.fields_by_name['total_share']._options = None
  _INSURANCEFUND.fields_by_name['total_share']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _REDEMPTIONSCHEDULE.fields_by_name['claimable_redemption_time']._options = None
  _REDEMPTIONSCHEDULE.fields_by_name['claimable_redemption_time']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037 yaml:\"claimable_redemption_time\"'
  _REDEMPTIONSCHEDULE.fields_by_name['redemption_amount']._options = None
  _REDEMPTIONSCHEDULE.fields_by_name['redemption_amount']._serialized_options = b'\310\336\037\000'
  _EVENTWITHDRAWREDEMPTION.fields_by_name['redeem_coin']._options = None
  _EVENTWITHDRAWREDEMPTION.fields_by_name['redeem_coin']._serialized_options = b'\310\336\037\000'
  _EVENTUNDERWRITE.fields_by_name['deposit']._options = None
  _EVENTUNDERWRITE.fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _EVENTUNDERWRITE.fields_by_name['shares']._options = None
  _EVENTUNDERWRITE.fields_by_name['shares']._serialized_options = b'\310\336\037\000'
  _PARAMS._serialized_start=235
  _PARAMS._serialized_end=390
  _INSURANCEFUND._serialized_start=393
  _INSURANCEFUND._serialized_end=885
  _REDEMPTIONSCHEDULE._serialized_start=888
  _REDEMPTIONSCHEDULE._serialized_end=1125
  _EVENTINSURANCEFUNDUPDATE._serialized_start=1127
  _EVENTINSURANCEFUNDUPDATE._serialized_end=1211
  _EVENTREQUESTREDEMPTION._serialized_start=1213
  _EVENTREQUESTREDEMPTION._serialized_end=1304
  _EVENTWITHDRAWREDEMPTION._serialized_start=1307
  _EVENTWITHDRAWREDEMPTION._serialized_end=1453
  _EVENTUNDERWRITE._serialized_start=1456
  _EVENTUNDERWRITE._serialized_end=1611
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&injective/oracle/v1beta1/genesis.proto\x12\x18injective.oracle.v1beta1\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x14gogoproto/gogo.proto\"\xc5\x07\n\x0cGenesisState\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32 .injective.oracle.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x15\n\rband_relayers\x18\x02 \x03(\t\x12\x43\n\x11\x62\x61nd_price_states\x18\x03 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceState\x12I\n\x17price_feed_price_states\x18\x04 \x03(\x0b\x32(.injective.oracle.v1beta1.PriceFeedState\x12K\n\x15\x63oinbase_price_states\x18\x05 \x03(\x0b\x32,.injective.oracle.v1beta1.CoinbasePriceState\x12G\n\x15\x62\x61nd_ibc_price_states\x18\x06 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceState\x12M\n\x18\x62\x61nd_ibc_oracle_requests\x18\x07 \x03(\x0b\x32+.injective.oracle.v1beta1.BandOracleRequest\x12\x46\n\x0f\x62\x61nd_ibc_params\x18\x08 \x01(\x0b\x32\'.injective.oracle.v1beta1.BandIBCParamsB\x04\xc8\xde\x1f\x00\x12!\n\x19\x62\x61nd_ibc_latest_client_id\x18\t \x01(\x04\x12\x42\n\x10\x63\x61lldata_records\x18\n \x03(\x0b\x32(.injective.oracle.v1beta1.CalldataRecord\x12\"\n\x1a\x62\x61nd_ibc_latest_request_id\x18\x0b \x01(\x04\x12M\n\x16\x63hainlink_price_states\x18\x0c \x03(\x0b\x32-.injective.oracle.v1beta1.ChainlinkPriceState\x12H\n\x18historical_price_records\x18\r \x03(\x0b\x32&.injective.oracle.v1beta1.PriceRecords\x12@\n\x0fprovider_states\x18\x0e \x03(\x0b\x32\'.injective.oracle.v1beta1.ProviderState\x12\x43\n\x11pyth_price_states\x18\x0f \x03(\x0b\x32(.injective.oracle.v1beta1.PythPriceState\"5\n\x0e\x43\x61lldataRecord\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61lldata\x18\x02 \x01(\x0c\x42NZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['band_ibc_params']._options = None
  _GENESISSTATE.fields_by_name['band_ibc_params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=130
  _GENESISSTATE._serialized_end=1095
  _CALLDATARECORD._serialized_start=1097
  _CALLDATARECORD._serialized_end=1150
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/consensus/wal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.consensus import types_pb2 as tendermint_dot_consensus_dot_types__pb2
from tendermint.types import events_pb2 as tendermint_dot_types_dot_events__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etendermint/consensus/wal.proto\x12\x14tendermint.consensus\x1a\x14gogoproto/gogo.proto\x1a tendermint/consensus/types.proto\x1a\x1dtendermint/types/events.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"X\n\x07MsgInfo\x12\x30\n\x03msg\x18\x01 \x01(\x0b\x32\x1d.tendermint.consensus.MessageB\x04\xc8\xde\x1f\x00\x12\x1b\n\x07peer_id\x18\x02 \x01(\tB\n\xe2\xde\x1f\x06PeerID\"q\n\x0bTimeoutInfo\x12\x35\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x05\x12\x0c\n\x04step\x18\x04 \x01(\r\"\x1b\n\tEndHeight\x12\x0e\n\x06height\x18\x01 \x01(\x03\"\x81\x02\n\nWALMessage\x12G\n\x16\x65vent_data_round_state\x18\x01 \x01(\x0b\x32%.tendermint.types.EventDataRoundStateH\x00\x12\x31\n\x08msg_info\x18\x02 \x01(\x0b\x32\x1d.tendermint.consensus.MsgInfoH\x00\x12\x39\n\x0ctimeout_info\x18\x03 \x01(\x0b\x32!.tendermint.consensus.TimeoutInfoH\x00\x12\x35\n\nend_height\x18\x04 \x01(\x0b\x32\x1f.tendermint.consensus.EndHeightH\x00\x42\x05\n\x03sum\"t\n\x0fTimedWALMessage\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12-\n\x03msg\x18\x02 \x01(\x0b\x32 .tendermint.consensus.WALMessageB=Z;github.com/tendermint/tendermint/proto/tendermint/consensusb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.consensus.wal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/tendermint/tendermint/proto/tendermint/consensus'
  _MSGINFO.fields_by_name['msg']._options = None
  _MSGINFO.fields_by_name['msg']._serialized_options = b'\310\336\037\000'
  _MSGINFO.fields_by_name['peer_id']._options = None
  _MSGINFO.fields_by_name['peer_id']._serialized_options = b'\342\336\037\006PeerID'
  _TIMEOUTINFO.fields_by_name['duration']._options = None
  _TIMEOUTINFO.fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _TIMEDWALMESSAGE.fields_by_name['time']._options = None
  _TIMEDWALMESSAGE.fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _MSGINFO._serialized_start=208
  _MSGINFO._serialized_end=296
  _TIMEOUTINFO._serialized_start=298
  _TIMEOUTINFO._serialized_end=411
  _ENDHEIGHT._serialized_start=413
  _ENDHEIGHT._serialized_end=440
  _WALMESSAGE._serialized_start=443
  _WALMESSAGE._serialized_end=700
  _TIMEDWALMESSAGE._serialized_start=702
  _TIMEDWALMESSAGE._serialized_end=818
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/authz/v1beta1/genesis.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x14gogoproto/gogo.proto\x1a cosmos/authz/v1beta1/authz.proto\"U\n\x0cGenesisState\x12\x45\n\rauthorization\x18\x01 \x03(\x0b\x32(.cosmos.authz.v1beta1.GrantAuthorizationB\x04\xc8\xde\x1f\x00\x42&Z$github.com/cosmos/cosmos-sdk/x/authzb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz'
  _GENESISSTATE.fields_by_name['authorization']._options = None
  _GENESISSTATE.fields_by_name['authorization']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=116
  _GENESISSTATE._serialized_end=201
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/vesting/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/vesting/v1beta1/tx.proto\x12\x16\x63osmos.vesting.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x8e\x02\n\x17MsgCreateVestingAccount\x12-\n\x0c\x66rom_address\x18\x01 \x01(\tB\x17\xf2\xde\x1f\x13yaml:\"from_address\"\x12)\n\nto_address\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"to_address\"\x12[\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12%\n\x08\x65nd_time\x18\x04 \x01(\x03\x42\x13\xf2\xde\x1f\x0fyaml:\"end_time\"\x12\x0f\n\x07\x64\x65layed\x18\x05 \x01(\x08:\x04\xe8\xa0\x1f\x01\"!\n\x1fMsgCreateVestingAccountResponse2\x88\x01\n\x03Msg\x12\x80\x01\n\x14\x43reateVestingAccount\x12/.cosmos.vesting.v1beta1.MsgCreateVestingAccount\x1a\x37.cosmos.vesting.v1beta1.MsgCreateVestingAccountResponseB3Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.vesting.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/types'
  _MSGCREATEVESTINGACCOUNT.fields_by_name['from_address']._options = None
  _MSGCREATEVESTINGACCOUNT.fields_by_name['from_address']._serialized_options = b'\362\336\037\023yaml:\"from_address\"'
  _MSGCREATEVESTINGACCOUNT.fields_by_name['to_address']._options = None
  _MSGCREATEVESTINGACCOUNT.fields_by_name['to_address']._serialized_options = b'\362\336\037\021yaml:\"to_address\"'
  _MSGCREATEVESTINGACCOUNT.fields_by_name['amount']._options = None
  _MSGCREATEVESTINGACCOUNT.fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGCREATEVESTINGACCOUNT.fields_by_name['end_time']._options = None
  _MSGCREATEVESTINGACCOUNT.fields_by_name['end_time']._serialized_options = b'\362\336\037\017yaml:\"end_time\"'
  _MSGCREATEVESTINGACCOUNT._options = None
  _MSGCREATEVESTINGACCOUNT._serialized_options = b'\350\240\037\001'
  _MSGCREATEVESTINGACCOUNT._serialized_start=114
  _MSGCREATEVESTINGACCOUNT._serialized_end=384
  _MSGCREATEVESTINGACCOUNTRESPONSE._serialized_start=386
  _MSGCREATEVESTINGACCOUNTRESPONSE._serialized_end=419
  _MSG._serialized_start=422
  _MSG._serialized_end=558
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/blockchain/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!tendermint/blockchain/types.proto\x12\x15tendermint.blockchain\x1a\x1ctendermint/types/block.proto\"\x1e\n\x0c\x42lockRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"!\n\x0fNoBlockResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\"7\n\rBlockResponse\x12&\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x17.tendermint.types.Block\"\x0f\n\rStatusRequest\".\n\x0eStatusResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\x03\"\xd5\x02\n\x07Message\x12<\n\rblock_request\x18\x01 \x01(\x0b\x32#.tendermint.blockchain.BlockRequestH\x00\x12\x43\n\x11no_block_response\x18\x02 \x01(\x0b\x32&.tendermint.blockchain.NoBlockResponseH\x00\x12>\n\x0e\x62lock_response\x18\x03 \x01(\x0b\x32$.tendermint.blockchain.BlockResponseH\x00\x12>\n\x0estatus_request\x18\x04 \x01(\x0b\x32$.tendermint.blockchain.StatusRequestH\x00\x12@\n\x0fstatus_response\x18\x05 \x01(\x0b\x32%.tendermint.blockchain.StatusResponseH\x00\x42\x05\n\x03sumB>Z<github.com/tendermint/tendermint/proto/tendermint/blockchainb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.blockchain.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/tendermint/tendermint/proto/tendermint/blockchain'
  _BLOCKREQUEST._serialized_start=90
  _BLOCKREQUEST._serialized_end=120
  _NOBLOCKRESPONSE._serialized_start=122
  _NOBLOCKRESPONSE._serialized_end=155
  _BLOCKRESPONSE._serialized_start=157
  _BLOCKRESPONSE._serialized_end=212
  _STATUSREQUEST._serialized_start=214
  _STATUSREQUEST._serialized_end=229
  _STATUSRESPONSE._serialized_start=231
  _STATUSRESPONSE._serialized_end=277
  _MESSAGE._serialized_start=280
  _MESSAGE._serialized_end=621
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/staking/v1beta1/tx.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a$cosmos/staking/v1beta1/staking.proto\"\xee\x03\n\x12MsgCreateValidator\x12>\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32#.cosmos.staking.v1beta1.DescriptionB\x04\xc8\xde\x1f\x00\x12\x41\n\ncommission\x18\x02 \x01(\x0b\x32\'.cosmos.staking.v1beta1.CommissionRatesB\x04\xc8\xde\x1f\x00\x12i\n\x13min_self_delegation\x18\x03 \x01(\tBL\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:\"min_self_delegation\"\xc8\xde\x1f\x00\x12\x37\n\x11\x64\x65legator_address\x18\x04 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x37\n\x11validator_address\x18\x05 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\"\x12>\n\x06pubkey\x18\x06 \x01(\x0b\x32\x14.google.protobuf.AnyB\x18\xca\xb4-\x14\x63osmos.crypto.PubKey\x12.\n\x05value\x18\x07 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1c\n\x1aMsgCreateValidatorResponse\"\xd1\x02\n\x10MsgEditValidator\x12>\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32#.cosmos.staking.v1beta1.DescriptionB\x04\xc8\xde\x1f\x00\x12-\n\x11validator_address\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12]\n\x0f\x63ommission_rate\x18\x03 \x01(\tBD\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x16yaml:\"commission_rate\"\x12\x65\n\x13min_self_delegation\x18\x04 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:\"min_self_delegation\":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1a\n\x18MsgEditValidatorResponse\"\xba\x01\n\x0bMsgDelegate\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x37\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\"\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x15\n\x13MsgDelegateResponse\"\x8a\x02\n\x12MsgBeginRedelegate\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12?\n\x15validator_src_address\x18\x02 \x01(\tB \xf2\xde\x1f\x1cyaml:\"validator_src_address\"\x12?\n\x15validator_dst_address\x18\x03 \x01(\tB \xf2\xde\x1f\x1cyaml:\"validator_dst_address\"\x12/\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"[\n\x1aMsgBeginRedelegateResponse\x12=\n\x0f\x63ompletion_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"\xbc\x01\n\rMsgUndelegate\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x37\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\"\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"V\n\x15MsgUndelegateResponse\x12=\n\x0f\x63ompletion_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x32\x9a\x04\n\x03Msg\x12q\n\x0f\x43reateValidator\x12*.cosmos.staking.v1beta1.MsgCreateValidator\x1a\x32.cosmos.staking.v1beta1.MsgCreateValidatorResponse\x12k\n\rEditValidator\x12(.cosmos.staking.v1beta1.MsgEditValidator\x1a\x30.cosmos.staking.v1beta1.MsgEditValidatorResponse\x12\\\n\x08\x44\x65legate\x12#.cosmos.staking.v1beta1.MsgDelegate\x1a+.cosmos.staking.v1beta1.MsgDelegateResponse\x12q\n\x0f\x42\x65ginRedelegate\x12*.cosmos.staking.v1beta1.MsgBeginRedelegate\x1a\x32.cosmos.staking.v1beta1.MsgBeginRedelegateResponse\x12\x62\n\nUndelegate\x12%.cosmos.staking.v1beta1.MsgUndelegate\x1a-.cosmos.staking.v1beta1.MsgUndelegateResponseB.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _MSGCREATEVALIDATOR.fields_by_name['description']._options = None
  _MSGCREATEVALIDATOR.fields_by_name['description']._serialized_options = b'\310\336\037\000'
  _MSGCREATEVALIDATOR.fields_by_name['commission']._options = None
  _MSGCREATEVALIDATOR.fields_by_name['commission']._serialized_options = b'\310\336\037\000'
  _MSGCREATEVALIDATOR.fields_by_name['min_self_delegation']._options = None
  _MSGCREATEVALIDATOR.fields_by_name['min_self_delegation']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\032yaml:\"min_self_delegation\"\310\336\037\000'
  _MSGCREATEVALIDATOR.fields_by_name['delegator_address']._options = None
  _MSGCREATEVALIDATOR.fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _MSGCREATEVALIDATOR.fields_by_name['validator_address']._options = None
  _MSGCREATEVALIDATOR.fields_by_name['validator_address']._serialized_options = b'\362\336\037\030yaml:\"validator_address\"'
  _MSGCREATEVALIDATOR.fields_by_name['pubkey']._options = None
  _MSGCREATEVALIDATOR.fields_by_name['pubkey']._serialized_options = b'\312\264-\024cosmos.crypto.PubKey'
  _MSGCREATEVALIDATOR.fields_by_name['value']._options = None
  _MSGCREATEVALIDATOR.fields_by_name['value']._serialized_options = b'\310\336\037\000'
  _MSGCREATEVALIDATOR._options = None
  _MSGCREATEVALIDATOR._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGEDITVALIDATOR.fields_by_name['description']._options = None
  _MSGEDITVALIDATOR.fields_by_name['description']._serialized_options = b'\310\336\037\000'
  _MSGEDITVALIDATOR.fields_by_name['validator_address']._options = None
  _MSGEDITVALIDATOR.fields_by_name['validator_address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _MSGEDITVALIDATOR.fields_by_name['commission_rate']._options = None
  _MSGEDITVALIDATOR.fields_by_name['commission_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\026yaml:\"commission_rate\"'
  _MSGEDITVALIDATOR.fields_by_name['min_self_delegation']._options = None
  _MSGEDITVALIDATOR.fields_by_name['min_self_delegation']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\032yaml:\"min_self_delegation\"'
  _MSGEDITVALIDATOR._options = None
  _MSGEDITVALIDATOR._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGDELEGATE.fields_by_name['delegator_address']._options = None
  _MSGDELEGATE.fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _MSGDELEGATE.fields_by_name['validator_address']._options = None
  _MSGDELEGATE.fields_by_name['validator_address']._serialized_options = b'\362\336\037\030yaml:\"validator_address\"'
  _MSGDELEGATE.fields_by_name['amount']._options = None
  _MSGDELEGATE.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGDELEGATE._options = None
  _MSGDELEGATE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGBEGINREDELEGATE.fields_by_name['delegator_address']._options = None
  _MSGBEGINREDELEGATE.fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _MSGBEGINREDELEGATE.fields_by_name['validator_src_address']._options = None
  _MSGBEGINREDELEGATE.fields_by_name['validator_src_address']._serialized_options = b'\362\336\037\034yaml:\"validator_src_address\"'
  _MSGBEGINREDELEGATE.fields_by_name['validator_dst_address']._options = None
  _MSGBEGINREDELEGATE.fields_by_name['validator_dst_address']._serialized_options = b'\362\336\037\034yaml:\"validator_dst_address\"'
  _MSGBEGINREDELEGATE.fields_by_name['amount']._options = None
  _MSGBEGINREDELEGATE.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGBEGINREDELEGATE._options = None
  _MSGBEGINREDELEGATE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGBEGINREDELEGATERESPONSE.fields_by_name['completion_time']._options = None
  _MSGBEGINREDELEGATERESPONSE.fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _MSGUNDELEGATE.fields_by_name['delegator_address']._options = None
  _MSGUNDELEGATE.fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _MSGUNDELEGATE.fields_by_name['validator_address']._options = None
  _MSGUNDELEGATE.fields_by_name['validator_address']._serialized_options = b'\362\336\037\030yaml:\"validator_address\"'
  _MSGUNDELEGATE.fields_by_name['amount']._options = None
  _MSGUNDELEGATE.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGUNDELEGATE._options = None
  _MSGUNDELEGATE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGUNDELEGATERESPONSE.fields_by_name['completion_time']._options = None
  _MSGUNDELEGATERESPONSE.fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _MSGCREATEVALIDATOR._serialized_start=239
  _MSGCREATEVALIDATOR._serialized_end=733
  _MSGCREATEVALIDATORRESPONSE._serialized_start=735
  _MSGCREATEVALIDATORRESPONSE._serialized_end=763
  _MSGEDITVALIDATOR._serialized_start=766
  _MSGEDITVALIDATOR._serialized_end=1103
  _MSGEDITVALIDATORRESPONSE._serialized_start=1105
  _MSGEDITVALIDATORRESPONSE._serialized_end=1131
  _MSGDELEGATE._serialized_start=1134
  _MSGDELEGATE._serialized_end=1320
  _MSGDELEGATERESPONSE._serialized_start=1322
  _MSGDELEGATERESPONSE._serialized_end=1343
  _MSGBEGINREDELEGATE._serialized_start=1346
  _MSGBEGINREDELEGATE._serialized_end=1612
  _MSGBEGINREDELEGATERESPONSE._serialized_start=1614
  _MSGBEGINREDELEGATERESPONSE._serialized_end=1705
  _MSGUNDELEGATE._serialized_start=1708
  _MSGUNDELEGATE._serialized_end=1896
  _MSGUNDELEGATERESPONSE._serialized_start=1898
  _MSGUNDELEGATERESPONSE._serialized_end=1984
  _MSG._serialized_start=1987
  _MSG._serialized_end=2525
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from injective.oracle.v1beta1 import genesis_pb2 as injective_dot_oracle_dot_v1beta1_dot_genesis__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/oracle/v1beta1/query.proto\x12\x18injective.oracle.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a&injective/oracle/v1beta1/genesis.proto\x1a\x14gogoproto/gogo.proto\")\n\x15QueryPythPriceRequest\x12\x10\n\x08price_id\x18\x01 \x01(\t\"W\n\x16QueryPythPriceResponse\x12=\n\x0bprice_state\x18\x01 \x01(\x0b\x32(.injective.oracle.v1beta1.PythPriceState\"\x14\n\x12QueryParamsRequest\"M\n\x13QueryParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32 .injective.oracle.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"\x1a\n\x18QueryBandRelayersRequest\"-\n\x19QueryBandRelayersResponse\x12\x10\n\x08relayers\x18\x01 \x03(\t\"\x1d\n\x1bQueryBandPriceStatesRequest\"^\n\x1cQueryBandPriceStatesResponse\x12>\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceState\" \n\x1eQueryBandIBCPriceStatesRequest\"a\n\x1fQueryBandIBCPriceStatesResponse\x12>\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceState\"\"\n QueryPriceFeedPriceStatesRequest\"c\n!QueryPriceFeedPriceStatesResponse\x12>\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.PriceFeedState\"!\n\x1fQueryCoinbasePriceStatesRequest\"f\n QueryCoinbasePriceStatesResponse\x12\x42\n\x0cprice_states\x18\x01 \x03(\x0b\x32,.injective.oracle.v1beta1.CoinbasePriceState\"\x1d\n\x1bQueryPythPriceStatesRequest\"^\n\x1cQueryPythPriceStatesResponse\x12>\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.PythPriceState\"B\n\x1eQueryProviderPriceStateRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\"\\\n\x1fQueryProviderPriceStateResponse\x12\x39\n\x0bprice_state\x18\x01 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceState\"\x19\n\x17QueryModuleStateRequest\"Q\n\x18QueryModuleStateResponse\x12\x35\n\x05state\x18\x01 \x01(\x0b\x32&.injective.oracle.v1beta1.GenesisState\"m\n\"QueryHistoricalPriceRecordsRequest\x12\x34\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x11\n\tsymbol_id\x18\x02 \x01(\t\"d\n#QueryHistoricalPriceRecordsResponse\x12=\n\rprice_records\x18\x01 \x03(\x0b\x32&.injective.oracle.v1beta1.PriceRecords\"^\n\x14OracleHistoryOptions\x12\x0f\n\x07max_age\x18\x01 \x01(\x04\x12\x1b\n\x13include_raw_history\x18\x02 \x01(\x08\x12\x18\n\x10include_metadata\x18\x03 \x01(\x08\"\xe1\x01\n\x1cQueryOracleVolatilityRequest\x12\x37\n\tbase_info\x18\x01 \x01(\x0b\x32$.injective.oracle.v1beta1.OracleInfo\x12\x38\n\nquote_info\x18\x02 \x01(\x0b\x32$.injective.oracle.v1beta1.OracleInfo\x12N\n\x16oracle_history_options\x18\x03 \x01(\x0b\x32..injective.oracle.v1beta1.OracleHistoryOptions\"\xe3\x01\n\x1dQueryOracleVolatilityResponse\x12>\n\nvolatility\x18\x01 \x01(\tB*\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x10history_metadata\x18\x02 \x01(\x0b\x32,.injective.oracle.v1beta1.MetadataStatistics\x12:\n\x0braw_history\x18\x03 \x03(\x0b\x32%.injective.oracle.v1beta1.PriceRecord\"!\n\x1fQueryOracleProvidersInfoRequest\"]\n QueryOracleProvidersInfoResponse\x12\x39\n\tproviders\x18\x01 \x03(\x0b\x32&.injective.oracle.v1beta1.ProviderInfo\"4\n QueryOracleProviderPricesRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\"c\n!QueryOracleProviderPricesResponse\x12>\n\rproviderState\x18\x01 \x03(\x0b\x32\'.injective.oracle.v1beta1.ProviderState\"q\n\x17QueryOraclePriceRequest\x12\x39\n\x0boracle_type\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\t\x12\r\n\x05quote\x18\x03 \x01(\t\"\xad\x03\n\x0ePricePairState\x12\x42\n\npair_price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\nbase_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0bquote_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12M\n\x15\x62\x61se_cumulative_price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16quote_cumulative_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x16\n\x0e\x62\x61se_timestamp\x18\x06 \x01(\x03\x12\x17\n\x0fquote_timestamp\x18\x07 \x01(\x03\"^\n\x18QueryOraclePriceResponse\x12\x42\n\x10price_pair_state\x18\x01 \x01(\x0b\x32(.injective.oracle.v1beta1.PricePairState2\xda\x15\n\x05Query\x12\x8f\x01\n\x06Params\x12,.injective.oracle.v1beta1.QueryParamsRequest\x1a-.injective.oracle.v1beta1.QueryParamsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /injective/oracle/v1beta1/params\x12\xa8\x01\n\x0c\x42\x61ndRelayers\x12\x32.injective.oracle.v1beta1.QueryBandRelayersRequest\x1a\x33.injective.oracle.v1beta1.QueryBandRelayersResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/injective/oracle/v1beta1/band_relayers\x12\xb5\x01\n\x0f\x42\x61ndPriceStates\x12\x35.injective.oracle.v1beta1.QueryBandPriceStatesRequest\x1a\x36.injective.oracle.v1beta1.QueryBandPriceStatesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/injective/oracle/v1beta1/band_price_states\x12\xc2\x01\n\x12\x42\x61ndIBCPriceStates\x12\x38.injective.oracle.v1beta1.QueryBandIBCPriceStatesRequest\x1a\x39.injective.oracle.v1beta1.QueryBandIBCPriceStatesResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/oracle/v1beta1/band_ibc_price_states\x12\xc9\x01\n\x14PriceFeedPriceStates\x12:.injective.oracle.v1beta1.QueryPriceFeedPriceStatesRequest\x1a;.injective.oracle.v1beta1.QueryPriceFeedPriceStatesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/oracle/v1beta1/pricefeed_price_states\x12\xc5\x01\n\x13\x43oinbasePriceStates\x12\x39.injective.oracle.v1beta1.QueryCoinbasePriceStatesRequest\x1a:.injective.oracle.v1beta1.QueryCoinbasePriceStatesResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/oracle/v1beta1/coinbase_price_states\x12\xb5\x01\n\x0fPythPriceStates\x12\x35.injective.oracle.v1beta1.QueryPythPriceStatesRequest\x1a\x36.injective.oracle.v1beta1.QueryPythPriceStatesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/injective/oracle/v1beta1/pyth_price_states\x12\xd5\x01\n\x12ProviderPriceState\x12\x38.injective.oracle.v1beta1.QueryProviderPriceStateRequest\x1a\x39.injective.oracle.v1beta1.QueryProviderPriceStateResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/injective/oracle/v1beta1/provider_price_state/{provider}/{symbol}\x12\xaa\x01\n\x11OracleModuleState\x12\x31.injective.oracle.v1beta1.QueryModuleStateRequest\x1a\x32.injective.oracle.v1beta1.QueryModuleStateResponse\".\x82\xd3\xe4\x93\x02(\x12&/injective/oracle/v1beta1/module_state\x12\xd1\x01\n\x16HistoricalPriceRecords\x12<.injective.oracle.v1beta1.QueryHistoricalPriceRecordsRequest\x1a=.injective.oracle.v1beta1.QueryHistoricalPriceRecordsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/oracle/v1beta1/historical_price_records\x12\xb1\x01\n\x10OracleVolatility\x12\x36.injective.oracle.v1beta1.QueryOracleVolatilityRequest\x1a\x37.injective.oracle.v1beta1.QueryOracleVolatilityResponse\",\x82\xd3\xe4\x93\x02&\x12$/injective/oracle/v1beta1/volatility\x12\xb9\x01\n\x13OracleProvidersInfo\x12\x39.injective.oracle.v1beta1.QueryOracleProvidersInfoRequest\x1a:.injective.oracle.v1beta1.QueryOracleProvidersInfoResponse\"+\x82\xd3\xe4\x93\x02%\x12#/injective/oracle/v1beta1/providers\x12\xc2\x01\n\x14OracleProviderPrices\x12:.injective.oracle.v1beta1.QueryOracleProviderPricesRequest\x1a;.injective.oracle.v1beta1.QueryOracleProviderPricesResponse\"1\x82\xd3\xe4\x93\x02+\x12)/injective/oracle/v1beta1/provider_prices\x12\x9d\x01\n\x0bOraclePrice\x12\x31.injective.oracle.v1beta1.QueryOraclePriceRequest\x1a\x32.injective.oracle.v1beta1.QueryOraclePriceResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/injective/oracle/v1beta1/price\x12\x9c\x01\n\tPythPrice\x12/.injective.oracle.v1beta1.QueryPythPriceRequest\x1a\x30.injective.oracle.v1beta1.QueryPythPriceResponse\",\x82\xd3\xe4\x93\x02&\x12$/injective/oracle/v1beta1/pyth_priceBNZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYORACLEVOLATILITYRESPONSE.fields_by_name['volatility']._options = None
  _QUERYORACLEVOLATILITYRESPONSE.fields_by_name['volatility']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PRICEPAIRSTATE.fields_by_name['pair_price']._options = None
  _PRICEPAIRSTATE.fields_by_name['pair_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PRICEPAIRSTATE.fields_by_name['base_price']._options = None
  _PRICEPAIRSTATE.fields_by_name['base_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PRICEPAIRSTATE.fields_by_name['quote_price']._options = None
  _PRICEPAIRSTATE.fields_by_name['quote_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PRICEPAIRSTATE.fields_by_name['base_cumulative_price']._options = None
  _PRICEPAIRSTATE.fields_by_name['base_cumulative_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PRICEPAIRSTATE.fields_by_name['quote_cumulative_price']._options = None
  _PRICEPAIRSTATE.fields_by_name['quote_cumulative_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\"\022 /injective/oracle/v1beta1/params'
  _QUERY.methods_by_name['BandRelayers']._options = None
  _QUERY.methods_by_name['BandRelayers']._serialized_options = b'\202\323\344\223\002)\022\'/injective/oracle/v1beta1/band_relayers'
  _QUERY.methods_by_name['BandPriceStates']._options = None
  _QUERY.methods_by_name['BandPriceStates']._serialized_options = b'\202\323\344\223\002-\022+/injective/oracle/v1beta1/band_price_states'
  _QUERY.methods_by_name['BandIBCPriceStates']._options = None
  _QUERY.methods_by_name['BandIBCPriceStates']._serialized_options = b'\202\323\344\223\0021\022//injective/oracle/v1beta1/band_ibc_price_states'
  _QUERY.methods_by_name['PriceFeedPriceStates']._options = None
  _QUERY.methods_by_name['PriceFeedPriceStates']._serialized_options = b'\202\323\344\223\0022\0220/injective/oracle/v1beta1/pricefeed_price_states'
  _QUERY.methods_by_name['CoinbasePriceStates']._options = None
  _QUERY.methods_by_name['CoinbasePriceStates']._serialized_options = b'\202\323\344\223\0021\022//injective/oracle/v1beta1/coinbase_price_states'
  _QUERY.methods_by_name['PythPriceStates']._options = None
  _QUERY.methods_by_name['PythPriceStates']._serialized_options = b'\202\323\344\223\002-\022+/injective/oracle/v1beta1/pyth_price_states'
  _QUERY.methods_by_name['ProviderPriceState']._options = None
  _QUERY.methods_by_name['ProviderPriceState']._serialized_options = b'\202\323\344\223\002D\022B/injective/oracle/v1beta1/provider_price_state/{provider}/{symbol}'
  _QUERY.methods_by_name['OracleModuleState']._options = None
  _QUERY.methods_by_name['OracleModuleState']._serialized_options = b'\202\323\344\223\002(\022&/injective/oracle/v1beta1/module_state'
  _QUERY.methods_by_name['HistoricalPriceRecords']._options = None
  _QUERY.methods_by_name['HistoricalPriceRecords']._serialized_options = b'\202\323\344\223\0024\0222/injective/oracle/v1beta1/historical_price_records'
  _QUERY.methods_by_name['OracleVolatility']._options = None
  _QUERY.methods_by_name['OracleVolatility']._serialized_options = b'\202\323\344\223\002&\022$/injective/oracle/v1beta1/volatility'
  _QUERY.methods_by_name['OracleProvidersInfo']._options = None
  _QUERY.methods_by_name['OracleProvidersInfo']._serialized_options = b'\202\323\344\223\002%\022#/injective/oracle/v1beta1/providers'
  _QUERY.methods_by_name['OracleProviderPrices']._options = None
  _QUERY.methods_by_name['OracleProviderPrices']._serialized_options = b'\202\323\344\223\002+\022)/injective/oracle/v1beta1/provider_prices'
  _QUERY.methods_by_name['OraclePrice']._options = None
  _QUERY.methods_by_name['OraclePrice']._serialized_options = b'\202\323\344\223\002!\022\037/injective/oracle/v1beta1/price'
  _QUERY.methods_by_name['PythPrice']._options = None
  _QUERY.methods_by_name['PythPrice']._serialized_options = b'\202\323\344\223\002&\022$/injective/oracle/v1beta1/pyth_price'
  _QUERYPYTHPRICEREQUEST._serialized_start=197
  _QUERYPYTHPRICEREQUEST._serialized_end=238
  _QUERYPYTHPRICERESPONSE._serialized_start=240
  _QUERYPYTHPRICERESPONSE._serialized_end=327
  _QUERYPARAMSREQUEST._serialized_start=329
  _QUERYPARAMSREQUEST._serialized_end=349
  _QUERYPARAMSRESPONSE._serialized_start=351
  _QUERYPARAMSRESPONSE._serialized_end=428
  _QUERYBANDRELAYERSREQUEST._serialized_start=430
  _QUERYBANDRELAYERSREQUEST._serialized_end=456
  _QUERYBANDRELAYERSRESPONSE._serialized_start=458
  _QUERYBANDRELAYERSRESPONSE._serialized_end=503
  _QUERYBANDPRICESTATESREQUEST._serialized_start=505
  _QUERYBANDPRICESTATESREQUEST._serialized_end=534
  _QUERYBANDPRICESTATESRESPONSE._serialized_start=536
  _QUERYBANDPRICESTATESRESPONSE._serialized_end=630
  _QUERYBANDIBCPRICESTATESREQUEST._serialized_start=632
  _QUERYBANDIBCPRICESTATESREQUEST._serialized_end=664
  _QUERYBANDIBCPRICESTATESRESPONSE._serialized_start=666
  _QUERYBANDIBCPRICESTATESRESPONSE._serialized_end=763
  _QUERYPRICEFEEDPRICESTATESREQUEST._serialized_start=765
  _QUERYPRICEFEEDPRICESTATESREQUEST._serialized_end=799
  _QUERYPRICEFEEDPRICESTATESRESPONSE._serialized_start=801
  _QUERYPRICEFEEDPRICESTATESRESPONSE._serialized_end=900
  _QUERYCOINBASEPRICESTATESREQUEST._serialized_start=902
  _QUERYCOINBASEPRICESTATESREQUEST._serialized_end=935
  _QUERYCOINBASEPRICESTATESRESPONSE._serialized_start=937
  _QUERYCOINBASEPRICESTATESRESPONSE._serialized_end=1039
  _QUERYPYTHPRICESTATESREQUEST._serialized_start=1041
  _QUERYPYTHPRICESTATESREQUEST._serialized_end=1070
  _QUERYPYTHPRICESTATESRESPONSE._serialized_start=1072
  _QUERYPYTHPRICESTATESRESPONSE._serialized_end=1166
  _QUERYPROVIDERPRICESTATEREQUEST._serialized_start=1168
  _QUERYPROVIDERPRICESTATEREQUEST._serialized_end=1234
  _QUERYPROVIDERPRICESTATERESPONSE._serialized_start=1236
  _QUERYPROVIDERPRICESTATERESPONSE._serialized_end=1328
  _QUERYMODULESTATEREQUEST._serialized_start=1330
  _QUERYMODULESTATEREQUEST._serialized_end=1355
  _QUERYMODULESTATERESPONSE._serialized_start=1357
  _QUERYMODULESTATERESPONSE._serialized_end=1438
  _QUERYHISTORICALPRICERECORDSREQUEST._serialized_start=1440
  _QUERYHISTORICALPRICERECORDSREQUEST._serialized_end=1549
  _QUERYHISTORICALPRICERECORDSRESPONSE._serialized_start=1551
  _QUERYHISTORICALPRICERECORDSRESPONSE._serialized_end=1651
  _ORACLEHISTORYOPTIONS._serialized_start=1653
  _ORACLEHISTORYOPTIONS._serialized_end=1747
  _QUERYORACLEVOLATILITYREQUEST._serialized_start=1750
  _QUERYORACLEVOLATILITYREQUEST._serialized_end=1975
  _QUERYORACLEVOLATILITYRESPONSE._serialized_start=1978
  _QUERYORACLEVOLATILITYRESPONSE._serialized_end=2205
  _QUERYORACLEPROVIDERSINFOREQUEST._serialized_start=2207
  _QUERYORACLEPROVIDERSINFOREQUEST._serialized_end=2240
  _QUERYORACLEPROVIDERSINFORESPONSE._serialized_start=2242
  _QUERYORACLEPROVIDERSINFORESPONSE._serialized_end=2335
  _QUERYORACLEPROVIDERPRICESREQUEST._serialized_start=2337
  _QUERYORACLEPROVIDERPRICESREQUEST._serialized_end=2389
  _QUERYORACLEPROVIDERPRICESRESPONSE._serialized_start=2391
  _QUERYORACLEPROVIDERPRICESRESPONSE._serialized_end=2490
  _QUERYORACLEPRICEREQUEST._serialized_start=2492
  _QUERYORACLEPRICEREQUEST._serialized_end=2605
  _PRICEPAIRSTATE._serialized_start=2608
  _PRICEPAIRSTATE._serialized_end=3037
  _QUERYORACLEPRICERESPONSE._serialized_start=3039
  _QUERYORACLEPRICERESPONSE._serialized_end=3133
  _QUERY._serialized_start=3136
  _QUERY._serialized_end=5914
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from injective.tokenfactory.v1beta1 import authorityMetadata_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_authorityMetadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+injective/tokenfactory/v1beta1/events.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x36injective/tokenfactory/v1beta1/authorityMetadata.proto\"4\n\x12\x45ventCreateTFDenom\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"^\n\x10\x45ventMintTFDenom\x12\x19\n\x11recipient_address\x18\x01 \x01(\t\x12/\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"[\n\x10\x45ventBurnTFDenom\x12\x16\n\x0e\x62urner_address\x18\x01 \x01(\t\x12/\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\">\n\x12\x45ventChangeTFAdmin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x19\n\x11new_admin_address\x18\x02 \x01(\t\"_\n\x17\x45ventSetTFDenomMetadata\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x35\n\x08metadata\x18\x02 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x04\xc8\xde\x1f\x00\x42TZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types'
  _EVENTMINTTFDENOM.fields_by_name['amount']._options = None
  _EVENTMINTTFDENOM.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _EVENTBURNTFDENOM.fields_by_name['amount']._options = None
  _EVENTBURNTFDENOM.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _EVENTSETTFDENOMMETADATA.fields_by_name['metadata']._options = None
  _EVENTSETTFDENOMMETADATA.fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _EVENTCREATETFDENOM._serialized_start=221
  _EVENTCREATETFDENOM._serialized_end=273
  _EVENTMINTTFDENOM._serialized_start=275
  _EVENTMINTTFDENOM._serialized_end=369
  _EVENTBURNTFDENOM._serialized_start=371
  _EVENTBURNTFDENOM._serialized_end=462
  _EVENTCHANGETFADMIN._serialized_start=464
  _EVENTCHANGETFADMIN._serialized_end=526
  _EVENTSETTFDENOMMETADATA._serialized_start=528
  _EVENTSETTFDENOMMETADATA._serialized_end=623
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.auction.v1beta1 import auction_pb2 as injective_dot_auction_dot_v1beta1_dot_auction__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/auction/v1beta1/genesis.proto\x12\x19injective.auction.v1beta1\x1a\'injective/auction/v1beta1/auction.proto\x1a\x14gogoproto/gogo.proto\"\xb5\x01\n\x0cGenesisState\x12\x37\n\x06params\x18\x01 \x01(\x0b\x32!.injective.auction.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x15\n\rauction_round\x18\x02 \x01(\x04\x12\x33\n\x0bhighest_bid\x18\x03 \x01(\x0b\x32\x1e.injective.auction.v1beta1.Bid\x12 \n\x18\x61uction_ending_timestamp\x18\x04 \x01(\x03\x42OZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.auction.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=134
  _GENESISSTATE._serialized_end=315
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/attestation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/peggy/v1/attestation.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"c\n\x0b\x41ttestation\x12\x10\n\x08observed\x18\x01 \x01(\x08\x12\r\n\x05votes\x18\x02 \x03(\t\x12\x0e\n\x06height\x18\x03 \x01(\x04\x12#\n\x05\x63laim\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"^\n\nERC20Token\x12\x10\n\x08\x63ontract\x18\x01 \x01(\t\x12>\n\x06\x61mount\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00*\x9f\x02\n\tClaimType\x12.\n\x12\x43LAIM_TYPE_UNKNOWN\x10\x00\x1a\x16\x8a\x9d \x12\x43LAIM_TYPE_UNKNOWN\x12.\n\x12\x43LAIM_TYPE_DEPOSIT\x10\x01\x1a\x16\x8a\x9d \x12\x43LAIM_TYPE_DEPOSIT\x12\x30\n\x13\x43LAIM_TYPE_WITHDRAW\x10\x02\x1a\x17\x8a\x9d \x13\x43LAIM_TYPE_WITHDRAW\x12<\n\x19\x43LAIM_TYPE_ERC20_DEPLOYED\x10\x03\x1a\x1d\x8a\x9d \x19\x43LAIM_TYPE_ERC20_DEPLOYED\x12<\n\x19\x43LAIM_TYPE_VALSET_UPDATED\x10\x04\x1a\x1d\x8a\x9d \x19\x43LAIM_TYPE_VALSET_UPDATED\x1a\x04\x88\xa3\x1e\x00\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.attestation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types'
  _CLAIMTYPE._options = None
  _CLAIMTYPE._serialized_options = b'\210\243\036\000'
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_UNKNOWN"]._options = None
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_UNKNOWN"]._serialized_options = b'\212\235 \022CLAIM_TYPE_UNKNOWN'
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_DEPOSIT"]._options = None
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_DEPOSIT"]._serialized_options = b'\212\235 \022CLAIM_TYPE_DEPOSIT'
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_WITHDRAW"]._options = None
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_WITHDRAW"]._serialized_options = b'\212\235 \023CLAIM_TYPE_WITHDRAW'
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_ERC20_DEPLOYED"]._options = None
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_ERC20_DEPLOYED"]._serialized_options = b'\212\235 \031CLAIM_TYPE_ERC20_DEPLOYED'
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_VALSET_UPDATED"]._options = None
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_VALSET_UPDATED"]._serialized_options = b'\212\235 \031CLAIM_TYPE_VALSET_UPDATED'
  _ERC20TOKEN.fields_by_name['amount']._options = None
  _ERC20TOKEN.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _CLAIMTYPE._serialized_start=307
  _CLAIMTYPE._serialized_end=594
  _ATTESTATION._serialized_start=109
  _ATTESTATION._serialized_end=208
  _ERC20TOKEN._serialized_start=210
  _ERC20TOKEN._serialized_end=304
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/rpc/grpc/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftendermint/rpc/grpc/types.proto\x12\x13tendermint.rpc.grpc\x1a\x1btendermint/abci/types.proto\"\r\n\x0bRequestPing\" \n\x12RequestBroadcastTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\"\x0e\n\x0cResponsePing\"\x81\x01\n\x13ResponseBroadcastTx\x12\x32\n\x08\x63heck_tx\x18\x01 \x01(\x0b\x32 .tendermint.abci.ResponseCheckTx\x12\x36\n\ndeliver_tx\x18\x02 \x01(\x0b\x32\".tendermint.abci.ResponseDeliverTx2\xbd\x01\n\x0c\x42roadcastAPI\x12K\n\x04Ping\x12 .tendermint.rpc.grpc.RequestPing\x1a!.tendermint.rpc.grpc.ResponsePing\x12`\n\x0b\x42roadcastTx\x12\'.tendermint.rpc.grpc.RequestBroadcastTx\x1a(.tendermint.rpc.grpc.ResponseBroadcastTxB4Z2github.com/tendermint/tendermint/rpc/grpc;coregrpcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.rpc.grpc.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/tendermint/tendermint/rpc/grpc;coregrpc'
  _REQUESTPING._serialized_start=85
  _REQUESTPING._serialized_end=98
  _REQUESTBROADCASTTX._serialized_start=100
  _REQUESTBROADCASTTX._serialized_end=132
  _RESPONSEPING._serialized_start=134
  _RESPONSEPING._serialized_end=148
  _RESPONSEBROADCASTTX._serialized_start=151
  _RESPONSEBROADCASTTX._serialized_end=280
  _BROADCASTAPI._serialized_start=283
  _BROADCASTAPI._serialized_end=472
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/slashing/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/slashing/v1beta1/tx.proto\x12\x17\x63osmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\"L\n\tMsgUnjail\x12\x35\n\x0evalidator_addr\x18\x01 \x01(\tB\x1d\xf2\xde\x1f\x0eyaml:\"address\"\xea\xde\x1f\x07\x61\x64\x64ress:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x01\"\x13\n\x11MsgUnjailResponse2_\n\x03Msg\x12X\n\x06Unjail\x12\".cosmos.slashing.v1beta1.MsgUnjail\x1a*.cosmos.slashing.v1beta1.MsgUnjailResponseB3Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa8\xe2\x1e\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types\250\342\036\001'
  _MSGUNJAIL.fields_by_name['validator_addr']._options = None
  _MSGUNJAIL.fields_by_name['validator_addr']._serialized_options = b'\362\336\037\016yaml:\"address\"\352\336\037\007address'
  _MSGUNJAIL._options = None
  _MSGUNJAIL._serialized_options = b'\210\240\037\000\230\240\037\001'
  _MSGUNJAIL._serialized_start=83
  _MSGUNJAIL._serialized_end=159
  _MSGUNJAILRESPONSE._serialized_start=161
  _MSGUNJAILRESPONSE._serialized_end=180
  _MSG._serialized_start=182
  _MSG._serialized_end=277
# @@protoc_insertion_point(module_scope)
